import { selector } from 'recoil';
import us from 'us';
import lodashGet from 'lodash/get';
import calendarAtom from '../atoms/calendar';
import multiSourceData from './multiSourceData';
const customCalendarNames = {
  'Washington, D.C.': 'District of Columbia',
  'U.S. Virgin Islands': 'Virgin Islands'
};

/**
 * Election calendar data.
 */
const calendar = selector({
  key: 'election.selectors.calendar',
  get: ({
    get
  }) => {
    const source = get(multiSourceData(calendarAtom.key));
    if (!source || !source.data) return undefined;
    const getFips = name => {
      const stateName = customCalendarNames[name] || name;
      return lodashGet(us.lookup(stateName), 'fips');
    };
    const data = {
      ...source.data.content,
      namedElections: source.data.content.namedElections.map(election => ({
        ...election,
        date: election.date.slice(0, 'YYYY-MM-DD'.length)
      })),
      electionEvents: source.data.content.electionEvents.map(election => ({
        ...election,
        date: election.date.slice(0, 'YYYY-MM-DD'.length),
        stateFips: getFips(election.state)
      }))
    };
    return {
      data,
      source
    };
  }
});
export default calendar;