import { AutoLayout } from "../../layout/index.js";
import { IfActive } from "../../application/index.js";
import PropTypes from "../../../utils/prop-types/index.js";
import cx from "../../../utils/css/cx.js";
import { ElectionLink, ElectionIcon } from "../index.js";
import DelegateCounterOvertime from '../DelegateCounterOvertime';
import classes from './styles.module.scss';
const cls = cx.merge(classes);
const EmbedDelegateTracker = function EmbedDelegateTracker({
  recirculationLinkPosition,
  description,
  party
}) {
  return <AutoLayout align="stretch" gap="5">
      <DelegateCounterOvertime description={description} party={party} eyebrow={{
      isLive: true,
      link: 'index:president',
      text: 'Pres. Delegate Tracker'
    }} />
      <IfActive active={recirculationLinkPosition === 'bottom'}>
        <ElectionLink to="index" className={cls('all-link')}>
          All 2024 Election Results
          <ElectionIcon type="LinkCaret" size="2" />
        </ElectionLink>
      </IfActive>
    </AutoLayout>;
};
EmbedDelegateTracker.defaultProps = {
  description: '',
  recirculationLinkPosition: 'bottom'
};
EmbedDelegateTracker.propTypes = {
  /**
   * The ID of the party to show delegate counts for
   */
  party: PropTypes.oneOf(['dem', 'gop']).isRequired,
  /**
   * The position of the recric link, which can appear at the
   * bottom of the lockup. Setting this prop to `none` will prevent the
   * link from rendering at all.
   */
  recirculationLinkPosition: PropTypes.oneOf(['bottom', 'none']),
  /**
   * The optional dek for the module
   */
  description: PropTypes.string
};
export default EmbedDelegateTracker;