import PropTypes from 'prop-types';
import { useModuleLastUpdated, usePageUpdateTime, usePageBuildTime } from "../../../hooks/election/index.js";
import { useFormattedTimestamp } from "../../../hooks/time/index.js";
import classes from './styles.module.scss';

/**
 * The last-updated timestamp of a module or page.
 */
const ModuleLastUpdated = function ModuleLastUpdated(props) {
  const {
    scope
  } = props;
  const moduleTime = useModuleLastUpdated();
  const pageTime = usePageUpdateTime();
  const buildTime = usePageBuildTime();
  const timestamps = {
    module: moduleTime,
    page: pageTime
  };
  const timestamp = timestamps[scope] || buildTime;
  const formatted = useFormattedTimestamp(timestamp);
  return <div className={classes.timestamp}>
      {`Updated ${formatted}`}
    </div>;
};
ModuleLastUpdated.defaultProps = {
  scope: 'module'
};
ModuleLastUpdated.propTypes = {
  /**
   * Specify the scope of the timestamp you want to use. A `module` scope uses
   * the last-updated time within the context of the containing module while
   * a `page` scope uses the last-updated time of the page as a whole.
   */
  scope: PropTypes.oneOf(['module', 'page'])
};
export default ModuleLastUpdated;