import PropTypes from 'prop-types';
import { useContestCollectionMetadata } from "../../../hooks/election/index.js";
import ModuleTitle from "../ModuleTitle/index.js";
import Leaderboard from "../Leaderboard/index.js";
import classes from './styles.module.scss';

/**
 * A collection of leaderboards to present in as a unified whole.
 */
const RacesToWatch = function RacesToWatch(props) {
  const {
    collectionId,
    headline,
    description,
    eyebrow,
    reporterNote
  } = props;
  const contests = useContestCollectionMetadata(collectionId);
  if (!contests) return null;
  return <div className={classes.container}>
      <ModuleTitle headline={headline || 'Races to watch'} description={description} eyebrow={eyebrow} reporterNote={reporterNote} disableBorder />
      <div className={classes.contests}>
        {Object.keys(contests).map(contestId => <div key={contestId} className={classes.contest}>
            <Leaderboard contestId={contestId} format="condensed" link="header" expandable="aggregationOnly" />
          </div>)}
      </div>
    </div>;
};
RacesToWatch.defaultProps = {
  headline: undefined,
  description: undefined,
  eyebrow: undefined,
  reporterNote: undefined
};
RacesToWatch.propTypes = {
  /**
   * The ID of the contest collection to use
   */
  collectionId: PropTypes.string.isRequired,
  /**
   * A custom headline for the module
   */
  headline: PropTypes.string,
  /**
   * A custom description for the module
   */
  description: PropTypes.string,
  /**
   * An eyebrow configuration for the module
   */
  eyebrow: PropTypes.shape({}),
  /**
   * A reporter annotation
   */
  reporterNote: PropTypes.shape({})
};
export default RacesToWatch;