import classnames from 'classnames';
import CandidateParty from "../../CandidateParty/index.jsx";
import CandidateIncumbentLabel from "../../CandidateIncumbentLabel/index.jsx";
import CandidatePolarity from "../../CandidatePolarity/index.jsx";
import CandidateName from "../../CandidateName/index.js";
import IfActive from "../../../application/IfActive/index.js";
import { useCandidateCallStatus } from "../../../../hooks/election/index.js";
import { useResultsTableFormatContext } from '../context';
import CandidateIcon from '../CandidateIcon';
import typography from '../typography.module.scss';
import classes from './styles.module.scss';
const CandidateHeader = function CandidateHeader(props) {
  const {
    candidateId,
    id
  } = props;
  const {
    showPolarity,
    candidateNameFormat,
    showPartyTags
  } = useResultsTableFormatContext();
  const candidateStatus = useCandidateCallStatus(id, candidateId);
  return <th scope="row" className={classes.container}>
      <span className={classes.flexContainer}>
        <CandidateIcon candidateId={candidateId} id={id} />
        <span className={classnames(classes.text, typography.cellText, {
        [typography.bold]: candidateStatus === 'winner'
      })}>
          <CandidateName id={candidateId} format={candidateNameFormat} />
          <CandidateIncumbentLabel id={candidateId} />
          {' '}
          <span className={classnames(classes.parenthetical, typography.label)}>
            <IfActive active={showPartyTags}>
              <CandidateParty id={candidateId} format="letter-parenthesis" />
            </IfActive>
            <IfActive active={showPolarity}>
              <CandidatePolarity id={candidateId} format="parenthesis" />
            </IfActive>
          </span>
        </span>
      </span>
    </th>;
};
export default CandidateHeader;