import classnames from 'classnames';
import AggregateCandidateVotes from "../../AggregateCandidateVotes/index.js";
import IfActive from "../../../application/IfActive/index.js";
import ElectionIcon from "../../ElectionIcon/index.js";
import { useMemo } from 'react';
import ExpandoButton from '../ExpandoButton';
import { useResultsTableFormatContext } from '../context';
import typography from '../typography.module.scss';
import classes from './styles.module.scss';
const OtherCandidatesRow = function OtherCandidatesRow(props) {
  const {
    id,
    candidateIds,
    isExpanded,
    setIsExpanded
  } = props;
  const {
    showVotes,
    expandable,
    size
  } = useResultsTableFormatContext();
  const showButton = expandable === 'expandableAggregation';
  const text = useMemo(() => {
    if (isExpanded) {
      return 'Collapse';
    }
    if (size === 'small') {
      return 'Others';
    }
    return 'Other candidates';
  }, [size, isExpanded]);
  const expandButtonSize = size === 'large' ? '4' : '3';
  return <>
      <th scope="row" className={classes.header}>
        <span className={classes.iconContainer}>
          <IfActive active={showButton}>
            <ExpandoButton isExpanded={isExpanded} setIsExpanded={setIsExpanded} size={expandButtonSize} showLabel={false} expandLabel="Show other candidates" collapseLabel="Collapse other candidates" id={id} />
          </IfActive>
          <IfActive active={!showButton}>
            <ElectionIcon type="CandidateSwatch" color="warmgray-70" size="2" />
          </IfActive>
        </span>
        <span className={classnames(classes.text, classes.left, typography.cellText)}>
          {text}
        </span>
      </th>

      <IfActive active={(!showButton || !isExpanded) && showVotes}>
        <td className={classnames(classes.cell, typography.cellText)}>
          <AggregateCandidateVotes id={id} candidateIds={candidateIds} />
        </td>

      </IfActive>

      <IfActive active={!showButton || !isExpanded}>
        <td className={classnames(classes.cell, classes.right, typography.cellText)}>
          <AggregateCandidateVotes id={id} candidateIds={candidateIds} format="percent" minimumFractionDigits={1} />
        </td>
      </IfActive>
    </>;
};
export default OtherCandidatesRow;